=======
History
=======

0.2.0 (2018-05-06)
------------------

* Full implementation of moodle math expressions.
* Added pi constant.
* Some math functions common between grade and answer calculation.

0.1.2 (2018-03-14)
------------------

* Use super method for init of derived classes.
* Removed support of python 3.3.
* Added basic definition of moodle mathematical variable classes (since 0.1.1).

0.1.0 (2018-03-08)
------------------

* First release on PyPI.
